Class: Google::Api::MethodSettings
- Inherits:
-
Object
- Object
- Google::Api::MethodSettings
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/api/client.rb
Overview
Describes the generator configuration for a method.
Defined Under Namespace
Classes: LongRunning
Instance Attribute Summary collapse
-
#auto_populated_fields ⇒ ::Array<::String>
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format.
-
#batching ⇒ ::Google::Api::BatchingConfigProto
Batching configuration for an API method in client libraries.
-
#long_running ⇒ ::Google::Api::MethodSettings::LongRunning
Describes settings to use for long-running operations when generating API methods for RPCs.
-
#selector ⇒ ::String
The fully qualified name of the method, for which the options below apply.
Instance Attribute Details
#auto_populated_fields ⇒ ::Array<::String>
Returns List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).format. Currently supported format: UUID4.
Example of a YAML configuration:
publishing:
method_settings:
- selector: google.example.v1.ExampleService.CreateExample
auto_populated_fields:
- request_id.
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'proto_docs/google/api/client.rb', line 412 class MethodSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes settings to use when generating API methods that use the # long-running operation pattern. # All default values below are from those used in the client library # generators (e.g. # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)). # @!attribute [rw] initial_poll_delay # @return [::Google::Protobuf::Duration] # Initial delay after which the first poll request will be made. # Default value: 5 seconds. # @!attribute [rw] poll_delay_multiplier # @return [::Float] # Multiplier to gradually increase delay between subsequent polls until it # reaches max_poll_delay. # Default value: 1.5. # @!attribute [rw] max_poll_delay # @return [::Google::Protobuf::Duration] # Maximum time between two subsequent poll requests. # Default value: 45 seconds. # @!attribute [rw] total_poll_timeout # @return [::Google::Protobuf::Duration] # Total polling timeout. # Default value: 5 minutes. class LongRunning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#batching ⇒ ::Google::Api::BatchingConfigProto
Returns Batching configuration for an API method in client libraries.
Example of a YAML configuration:
publishing:
method_settings:
- selector: google.example.v1.ExampleService.BatchCreateExample
batching:
element_count_threshold: 1000
request_byte_threshold: 100000000
delay_threshold_millis: 10.
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'proto_docs/google/api/client.rb', line 412 class MethodSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes settings to use when generating API methods that use the # long-running operation pattern. # All default values below are from those used in the client library # generators (e.g. # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)). # @!attribute [rw] initial_poll_delay # @return [::Google::Protobuf::Duration] # Initial delay after which the first poll request will be made. # Default value: 5 seconds. # @!attribute [rw] poll_delay_multiplier # @return [::Float] # Multiplier to gradually increase delay between subsequent polls until it # reaches max_poll_delay. # Default value: 1.5. # @!attribute [rw] max_poll_delay # @return [::Google::Protobuf::Duration] # Maximum time between two subsequent poll requests. # Default value: 45 seconds. # @!attribute [rw] total_poll_timeout # @return [::Google::Protobuf::Duration] # Total polling timeout. # Default value: 5 minutes. class LongRunning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#long_running ⇒ ::Google::Api::MethodSettings::LongRunning
Returns Describes settings to use for long-running operations when generating API methods for RPCs. Complements RPCs that use the annotations in google/longrunning/operations.proto.
Example of a YAML configuration::
publishing:
method_settings:
- selector: google.cloud.speech.v2.Speech.BatchRecognize
long_running:
initial_poll_delay: 60s # 1 minute
poll_delay_multiplier: 1.5
max_poll_delay: 360s # 6 minutes
total_poll_timeout: 54000s # 90 minutes.
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'proto_docs/google/api/client.rb', line 412 class MethodSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes settings to use when generating API methods that use the # long-running operation pattern. # All default values below are from those used in the client library # generators (e.g. # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)). # @!attribute [rw] initial_poll_delay # @return [::Google::Protobuf::Duration] # Initial delay after which the first poll request will be made. # Default value: 5 seconds. # @!attribute [rw] poll_delay_multiplier # @return [::Float] # Multiplier to gradually increase delay between subsequent polls until it # reaches max_poll_delay. # Default value: 1.5. # @!attribute [rw] max_poll_delay # @return [::Google::Protobuf::Duration] # Maximum time between two subsequent poll requests. # Default value: 45 seconds. # @!attribute [rw] total_poll_timeout # @return [::Google::Protobuf::Duration] # Total polling timeout. # Default value: 5 minutes. class LongRunning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#selector ⇒ ::String
Returns The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options.
Example:
publishing:
method_settings:
- selector: google.storage.control.v2.StorageControl.CreateFolder
# method settings for CreateFolder...
412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'proto_docs/google/api/client.rb', line 412 class MethodSettings include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes settings to use when generating API methods that use the # long-running operation pattern. # All default values below are from those used in the client library # generators (e.g. # [Java](https://github.com/googleapis/gapic-generator-java/blob/04c2faa191a9b5a10b92392fe8482279c4404803/src/main/java/com/google/api/generator/gapic/composer/common/RetrySettingsComposer.java)). # @!attribute [rw] initial_poll_delay # @return [::Google::Protobuf::Duration] # Initial delay after which the first poll request will be made. # Default value: 5 seconds. # @!attribute [rw] poll_delay_multiplier # @return [::Float] # Multiplier to gradually increase delay between subsequent polls until it # reaches max_poll_delay. # Default value: 1.5. # @!attribute [rw] max_poll_delay # @return [::Google::Protobuf::Duration] # Maximum time between two subsequent poll requests. # Default value: 45 seconds. # @!attribute [rw] total_poll_timeout # @return [::Google::Protobuf::Duration] # Total polling timeout. # Default value: 5 minutes. class LongRunning include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |