Class: Google::Cloud::ConfigService::V1::AutoMigrationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

AutoMigrationConfig contains the automigration configuration for a project.

Instance Attribute Summary collapse

Instance Attribute Details

#auto_migration_enabled::Boolean

Returns Optional. Whether the auto migration is enabled for the project.

Returns:

  • (::Boolean)

    Optional. Whether the auto migration is enabled for the project.



2165
2166
2167
2168
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2165

class AutoMigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The name of the AutoMigrationConfig. Format: 'projects/{project_id}/locations/{location}/AutoMigrationConfig'.

Returns:

  • (::String)

    Identifier. The name of the AutoMigrationConfig. Format: 'projects/{project_id}/locations/{location}/AutoMigrationConfig'.



2165
2166
2167
2168
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2165

class AutoMigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time the AutoMigrationConfig was last updated.

Returns:



2165
2166
2167
2168
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2165

class AutoMigrationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end