Class: Google::Cloud::ConfigService::V1::CreateDeploymentGroupRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

A request to create a deployment group

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_group::Google::Cloud::ConfigService::V1::DeploymentGroup

Returns Required. [Deployment Group][] resource to create.

Returns:



557
558
559
560
# File 'proto_docs/google/cloud/config/v1/config.rb', line 557

class CreateDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment_group_id::String

Returns Required. The deployment group ID.

Returns:

  • (::String)

    Required. The deployment group ID.



557
558
559
560
# File 'proto_docs/google/cloud/config/v1/config.rb', line 557

class CreateDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent in whose context the Deployment Group is created. The parent value is in the format: 'projects/{project_id}/locations/{location}'.

Returns:

  • (::String)

    Required. The parent in whose context the Deployment Group is created. The parent value is in the format: 'projects/{project_id}/locations/{location}'



557
558
559
560
# File 'proto_docs/google/cloud/config/v1/config.rb', line 557

class CreateDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#request_id::String

Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

Returns:

  • (::String)

    Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.

    For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

    The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).



557
558
559
560
# File 'proto_docs/google/cloud/config/v1/config.rb', line 557

class CreateDeploymentGroupRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end