Class: Google::Cloud::ConfigService::V1::DeploymentGroup

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

A DeploymentGroup is a collection of DeploymentUnits that in a DAG-like structure.

Defined Under Namespace

Modules: ProvisioningState, State Classes: AnnotationsEntry, LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. Arbitrary key-value metadata storage e.g. to help client tools identify deployment group during automation. See https://google.aip.dev/148#annotations for details on format and size limitations.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Arbitrary key-value metadata storage e.g. to help client tools identify deployment group during automation. See https://google.aip.dev/148#annotations for details on format and size limitations.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the deployment group was created.

Returns:



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#deployment_units::Array<::Google::Cloud::ConfigService::V1::DeploymentUnit>

The deployment units of the deployment group in a DAG like structure. When a deployment group is being provisioned, the deployment units are deployed in a DAG order. The provided units must be in a DAG order, otherwise an error will be returned.

Returns:

  • (::Array<::Google::Cloud::ConfigService::V1::DeploymentUnit>)

    The deployment units of the deployment group in a DAG like structure. When a deployment group is being provisioned, the deployment units are deployed in a DAG order. The provided units must be in a DAG order, otherwise an error will be returned.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. User-defined metadata for the deployment group.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. User-defined metadata for the deployment group.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#name::String

Returns Identifier. The name of the deployment group. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.

Returns:

  • (::String)

    Identifier. The name of the deployment group. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#provisioning_error::Google::Rpc::Status (readonly)

Returns Output only. The error status of the deployment group provisioning or deprovisioning.

Returns:

  • (::Google::Rpc::Status)

    Output only. The error status of the deployment group provisioning or deprovisioning.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#provisioning_state::Google::Cloud::ConfigService::V1::DeploymentGroup::ProvisioningState (readonly)

Returns Output only. The provisioning state of the deployment group.

Returns:



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#provisioning_state_description::String (readonly)

Returns Output only. Additional information regarding the current provisioning state.

Returns:

  • (::String)

    Output only. Additional information regarding the current provisioning state.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#state::Google::Cloud::ConfigService::V1::DeploymentGroup::State (readonly)

Returns Output only. Current state of the deployment group.

Returns:



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#state_description::String (readonly)

Returns Output only. Additional information regarding the current state.

Returns:

  • (::String)

    Output only. Additional information regarding the current state.



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. Time when the deployment group was last updated.

Returns:



2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
2244
2245
2246
2247
2248
2249
2250
2251
2252
2253
2254
2255
2256
2257
2258
2259
2260
2261
2262
2263
2264
2265
2266
2267
2268
2269
2270
2271
2272
2273
2274
2275
2276
2277
2278
2279
2280
2281
2282
2283
2284
2285
2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
2302
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2229

class DeploymentGroup
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible states of a deployment group.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # The deployment group is being created.
    CREATING = 1

    # The deployment group is healthy.
    ACTIVE = 2

    # The deployment group is being updated.
    UPDATING = 3

    # The deployment group is being deleted.
    DELETING = 4

    # The deployment group has encountered an unexpected error.
    FAILED = 5

    # The deployment group is no longer being actively reconciled.
    # This may be the result of recovering the project after deletion.
    SUSPENDED = 6

    # The deployment group has been deleted.
    DELETED = 7
  end

  # Possible provisioning states of a deployment group.
  module ProvisioningState
    # Unspecified provisioning state.
    PROVISIONING_STATE_UNSPECIFIED = 0

    # The deployment group is being provisioned.
    PROVISIONING = 1

    # The deployment group is provisioned.
    PROVISIONED = 2

    # The deployment group failed to be provisioned.
    FAILED_TO_PROVISION = 3

    # The deployment group is being deprovisioned.
    DEPROVISIONING = 4

    # The deployment group is deprovisioned.
    DEPROVISIONED = 5

    # The deployment group failed to be deprovisioned.
    FAILED_TO_DEPROVISION = 6
  end
end