Module: Google::Cloud::ConfigService::V1::DeploymentGroup::State

Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

Possible states of a deployment group.

Constant Summary collapse

STATE_UNSPECIFIED =

The default value. This value is used if the state is omitted.

0
CREATING =

The deployment group is being created.

1
ACTIVE =

The deployment group is healthy.

2
UPDATING =

The deployment group is being updated.

3
DELETING =

The deployment group is being deleted.

4
FAILED =

The deployment group has encountered an unexpected error.

5
SUSPENDED =

The deployment group is no longer being actively reconciled. This may be the result of recovering the project after deletion.

6
DELETED =

The deployment group has been deleted.

7