Class: Google::Cloud::ConfigService::V1::DeploymentOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

Ephemeral metadata content describing the state of a deployment operation.

Defined Under Namespace

Modules: DeploymentStep

Instance Attribute Summary collapse

Instance Attribute Details

#apply_results::Google::Cloud::ConfigService::V1::ApplyResults

Returns Outputs and artifacts from applying a deployment.

Returns:



989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'proto_docs/google/cloud/config/v1/config.rb', line 989

class DeploymentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment may be running.
  module DeploymentStep
    # Unspecified deployment step
    DEPLOYMENT_STEP_UNSPECIFIED = 0

    # Infra Manager is creating a Google Cloud Storage bucket to store
    # artifacts and metadata about the deployment and revision
    PREPARING_STORAGE_BUCKET = 1

    # Downloading the blueprint onto the Google Cloud Storage bucket
    DOWNLOADING_BLUEPRINT = 2

    # Initializing Terraform using `terraform init`
    RUNNING_TF_INIT = 3

    # Running `terraform plan`
    RUNNING_TF_PLAN = 4

    # Actuating resources using Terraform using `terraform apply`
    RUNNING_TF_APPLY = 5

    # Destroying resources using Terraform using `terraform destroy`
    RUNNING_TF_DESTROY = 6

    # Validating the uploaded TF state file when unlocking a deployment
    RUNNING_TF_VALIDATE = 7

    # Unlocking a deployment
    UNLOCKING_DEPLOYMENT = 8

    # Operation was successful
    SUCCEEDED = 9

    # Operation failed
    FAILED = 10

    # Validating the provided repository.
    VALIDATING_REPOSITORY = 11

    # Running quota validation
    RUNNING_QUOTA_VALIDATION = 12
  end
end

#build::String (readonly)

Returns Output only. Cloud Build instance UUID associated with this operation.

Returns:

  • (::String)

    Output only. Cloud Build instance UUID associated with this operation.



989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'proto_docs/google/cloud/config/v1/config.rb', line 989

class DeploymentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment may be running.
  module DeploymentStep
    # Unspecified deployment step
    DEPLOYMENT_STEP_UNSPECIFIED = 0

    # Infra Manager is creating a Google Cloud Storage bucket to store
    # artifacts and metadata about the deployment and revision
    PREPARING_STORAGE_BUCKET = 1

    # Downloading the blueprint onto the Google Cloud Storage bucket
    DOWNLOADING_BLUEPRINT = 2

    # Initializing Terraform using `terraform init`
    RUNNING_TF_INIT = 3

    # Running `terraform plan`
    RUNNING_TF_PLAN = 4

    # Actuating resources using Terraform using `terraform apply`
    RUNNING_TF_APPLY = 5

    # Destroying resources using Terraform using `terraform destroy`
    RUNNING_TF_DESTROY = 6

    # Validating the uploaded TF state file when unlocking a deployment
    RUNNING_TF_VALIDATE = 7

    # Unlocking a deployment
    UNLOCKING_DEPLOYMENT = 8

    # Operation was successful
    SUCCEEDED = 9

    # Operation failed
    FAILED = 10

    # Validating the provided repository.
    VALIDATING_REPOSITORY = 11

    # Running quota validation
    RUNNING_QUOTA_VALIDATION = 12
  end
end

#logs::String (readonly)

Returns Output only. Location of Deployment operations logs in gs://{bucket}/{object} format.

Returns:

  • (::String)

    Output only. Location of Deployment operations logs in gs://{bucket}/{object} format.



989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'proto_docs/google/cloud/config/v1/config.rb', line 989

class DeploymentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment may be running.
  module DeploymentStep
    # Unspecified deployment step
    DEPLOYMENT_STEP_UNSPECIFIED = 0

    # Infra Manager is creating a Google Cloud Storage bucket to store
    # artifacts and metadata about the deployment and revision
    PREPARING_STORAGE_BUCKET = 1

    # Downloading the blueprint onto the Google Cloud Storage bucket
    DOWNLOADING_BLUEPRINT = 2

    # Initializing Terraform using `terraform init`
    RUNNING_TF_INIT = 3

    # Running `terraform plan`
    RUNNING_TF_PLAN = 4

    # Actuating resources using Terraform using `terraform apply`
    RUNNING_TF_APPLY = 5

    # Destroying resources using Terraform using `terraform destroy`
    RUNNING_TF_DESTROY = 6

    # Validating the uploaded TF state file when unlocking a deployment
    RUNNING_TF_VALIDATE = 7

    # Unlocking a deployment
    UNLOCKING_DEPLOYMENT = 8

    # Operation was successful
    SUCCEEDED = 9

    # Operation failed
    FAILED = 10

    # Validating the provided repository.
    VALIDATING_REPOSITORY = 11

    # Running quota validation
    RUNNING_QUOTA_VALIDATION = 12
  end
end

#step::Google::Cloud::ConfigService::V1::DeploymentOperationMetadata::DeploymentStep

Returns The current step the deployment operation is running.

Returns:



989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
# File 'proto_docs/google/cloud/config/v1/config.rb', line 989

class DeploymentOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment may be running.
  module DeploymentStep
    # Unspecified deployment step
    DEPLOYMENT_STEP_UNSPECIFIED = 0

    # Infra Manager is creating a Google Cloud Storage bucket to store
    # artifacts and metadata about the deployment and revision
    PREPARING_STORAGE_BUCKET = 1

    # Downloading the blueprint onto the Google Cloud Storage bucket
    DOWNLOADING_BLUEPRINT = 2

    # Initializing Terraform using `terraform init`
    RUNNING_TF_INIT = 3

    # Running `terraform plan`
    RUNNING_TF_PLAN = 4

    # Actuating resources using Terraform using `terraform apply`
    RUNNING_TF_APPLY = 5

    # Destroying resources using Terraform using `terraform destroy`
    RUNNING_TF_DESTROY = 6

    # Validating the uploaded TF state file when unlocking a deployment
    RUNNING_TF_VALIDATE = 7

    # Unlocking a deployment
    UNLOCKING_DEPLOYMENT = 8

    # Operation was successful
    SUCCEEDED = 9

    # Operation failed
    FAILED = 10

    # Validating the provided repository.
    VALIDATING_REPOSITORY = 11

    # Running quota validation
    RUNNING_QUOTA_VALIDATION = 12
  end
end