Class: Google::Cloud::ConfigService::V1::DeploymentSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

Spec for a deployment to be created.

Instance Attribute Summary collapse

Instance Attribute Details

#deployment::Google::Cloud::ConfigService::V1::Deployment

Returns Required. The deployment to be created.

Returns:



2333
2334
2335
2336
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2333

class DeploymentSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#deployment_id::String

Returns Required. The id of the deployment to be created which doesn't include the project id and location.

Returns:

  • (::String)

    Required. The id of the deployment to be created which doesn't include the project id and location.



2333
2334
2335
2336
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2333

class DeploymentSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end