Class: Google::Cloud::ConfigService::V1::DeploymentUnitProgress

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The progress of a deployment unit provisioning or deprovisioning.

Defined Under Namespace

Modules: Intent, State

Instance Attribute Summary collapse

Instance Attribute Details

#deployment::String (readonly)

Returns Output only. The name of the deployment to be provisioned. Format: 'projects/{project}/locations/{location}/deployments/{deployment}'.

Returns:

  • (::String)

    Output only. The name of the deployment to be provisioned. Format: 'projects/{project}/locations/{location}/deployments/{deployment}'.



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#deployment_operation_summary::Google::Cloud::ConfigService::V1::DeploymentOperationSummary (readonly)

Returns Output only. The summary of the deployment operation.

Returns:



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#error::Google::Rpc::Status (readonly)

Returns Output only. Holds the error status of the deployment unit provisioning.

Returns:



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#intent::Google::Cloud::ConfigService::V1::DeploymentUnitProgress::Intent (readonly)

Returns Output only. The intent of the deployment unit.

Returns:



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#state::Google::Cloud::ConfigService::V1::DeploymentUnitProgress::State (readonly)

Returns Output only. The current step of the deployment unit provisioning.

Returns:



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#state_description::String (readonly)

Returns Output only. Additional information regarding the current state.

Returns:

  • (::String)

    Output only. Additional information regarding the current state.



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end

#unit_id::String (readonly)

Returns Output only. The unit id of the deployment unit to be provisioned.

Returns:

  • (::String)

    Output only. The unit id of the deployment unit to be provisioned.



2511
2512
2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
2530
2531
2532
2533
2534
2535
2536
2537
2538
2539
2540
2541
2542
2543
2544
2545
2546
2547
2548
2549
2550
2551
2552
2553
2554
2555
2556
2557
2558
2559
2560
2561
2562
2563
2564
2565
2566
2567
2568
2569
2570
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2511

class DeploymentUnitProgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The possible steps a deployment unit provisioning may be running.
  module State
    # The default value. This value is unused.
    STATE_UNSPECIFIED = 0

    # The deployment unit is queued for deployment creation or update.
    QUEUED = 1

    # The underlying deployment of the unit is being created or updated.
    APPLYING_DEPLOYMENT = 2

    # The underlying deployment operation of the unit has succeeded.
    SUCCEEDED = 4

    # The underlying deployment operation of the unit has failed.
    FAILED = 5

    # The deployment unit was aborted, likely due to failures in other
    # dependent deployment units.
    ABORTED = 6

    # The deployment unit was skipped because there were no changes to apply.
    SKIPPED = 7

    # The deployment is being deleted.
    DELETING_DEPLOYMENT = 8

    # The deployment is being previewed.
    PREVIEWING_DEPLOYMENT = 9
  end

  # The possible intents of a deployment unit.
  module Intent
    # Unspecified intent.
    INTENT_UNSPECIFIED = 0

    # Create deployment in the unit from the deployment spec.
    CREATE_DEPLOYMENT = 1

    # Update deployment in the unit.
    UPDATE_DEPLOYMENT = 2

    # Delete deployment in the unit.
    DELETE_DEPLOYMENT = 3

    # Recreate deployment in the unit.
    RECREATE_DEPLOYMENT = 4

    # Delete deployment in latest successful revision while no longer
    # referenced in any deployment unit in the current deployment group.
    CLEAN_UP = 5

    # Expected to be unchanged.
    UNCHANGED = 6
  end
end