Module: Google::Cloud::ConfigService::V1::DeploymentUnitProgress::Intent

Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The possible intents of a deployment unit.

Constant Summary collapse

INTENT_UNSPECIFIED =

Unspecified intent.

0
CREATE_DEPLOYMENT =

Create deployment in the unit from the deployment spec.

1
UPDATE_DEPLOYMENT =

Update deployment in the unit.

2
DELETE_DEPLOYMENT =

Delete deployment in the unit.

3
RECREATE_DEPLOYMENT =

Recreate deployment in the unit.

4
CLEAN_UP =

Delete deployment in latest successful revision while no longer referenced in any deployment unit in the current deployment group.

5
UNCHANGED =

Expected to be unchanged.

6