Class: Google::Cloud::ConfigService::V1::GetDeploymentGroupRevisionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The request message for the GetDeploymentGroupRevision method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the deployment group revision to retrieve. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}/revisions/{revision}'.

Returns:

  • (::String)

    Required. The name of the deployment group revision to retrieve. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}/revisions/{revision}'.



2642
2643
2644
2645
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2642

class GetDeploymentGroupRevisionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end