Class: Google::Cloud::ConfigService::V1::ListDeploymentGroupRevisionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The request message for the ListDeploymentGroupRevisions method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. When requesting a page of resources, 'page_size' specifies number of resources to return. If unspecified, a sensible default will be used by the server. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. When requesting a page of resources, 'page_size' specifies number of resources to return. If unspecified, a sensible default will be used by the server. The maximum value is 1000; values above 1000 will be coerced to 1000.



2666
2667
2668
2669
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2666

class ListDeploymentGroupRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Token returned by previous call to 'ListDeploymentGroupRevisions' which specifies the position in the list from where to continue listing the deployment group revisions. All other parameters provided to ListDeploymentGroupRevisions must match the call that provided the page token.

Returns:

  • (::String)

    Optional. Token returned by previous call to 'ListDeploymentGroupRevisions' which specifies the position in the list from where to continue listing the deployment group revisions. All other parameters provided to ListDeploymentGroupRevisions must match the call that provided the page token.



2666
2667
2668
2669
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2666

class ListDeploymentGroupRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of deployment group revisions. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.

Returns:

  • (::String)

    Required. The parent, which owns this collection of deployment group revisions. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.



2666
2667
2668
2669
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2666

class ListDeploymentGroupRevisionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end