Class: Google::Cloud::ConfigService::V1::ListDeploymentGroupRevisionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The response message for the ListDeploymentGroupRevisions method.

Instance Attribute Summary collapse

Instance Attribute Details

#deployment_group_revisions::Array<::Google::Cloud::ConfigService::V1::DeploymentGroupRevision>

Returns The deployment group revisions from the specified collection.

Returns:



2682
2683
2684
2685
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2682

class ListDeploymentGroupRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Token to be supplied to the next ListDeploymentGroupRevisions request via page_token to obtain the next set of results.

Returns:

  • (::String)

    Token to be supplied to the next ListDeploymentGroupRevisions request via page_token to obtain the next set of results.



2682
2683
2684
2685
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2682

class ListDeploymentGroupRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that could not be reached.



2682
2683
2684
2685
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2682

class ListDeploymentGroupRevisionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end