Class: Google::Cloud::ConfigService::V1::ListDeploymentGroupsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

The request message for the ListDeploymentGroups method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Lists the DeploymentGroups that match the filter expression. A filter expression filters the deployment groups listed in the response. The expression must be of the form '{field} {operator} {value}' where operators: '<', '>', '<=', '>=', '!=', '=', ':' are supported (colon ':' represents a HAS operator which is roughly synonymous with equality). {field} can refer to a proto or JSON field, or a synthetic field. Field names can be camelCase or snake_case.

Examples:

  • Filter by name: name = "projects/foo/locations/us-central1/deploymentGroups/bar"

  • Filter by labels:

    • Resources that have a key called 'foo' labels.foo:*
    • Resources that have a key called 'foo' whose value is 'bar' labels.foo = bar
  • Filter by state:

    • DeploymentGroups in CREATING state. state=CREATING.

Returns:

  • (::String)

    Optional. Lists the DeploymentGroups that match the filter expression. A filter expression filters the deployment groups listed in the response. The expression must be of the form '{field} {operator} {value}' where operators: '<', '>', '<=', '>=', '!=', '=', ':' are supported (colon ':' represents a HAS operator which is roughly synonymous with equality). {field} can refer to a proto or JSON field, or a synthetic field. Field names can be camelCase or snake_case.

    Examples:

    • Filter by name: name = "projects/foo/locations/us-central1/deploymentGroups/bar"

    • Filter by labels:

      • Resources that have a key called 'foo' labels.foo:*
      • Resources that have a key called 'foo' whose value is 'bar' labels.foo = bar
    • Filter by state:

      • DeploymentGroups in CREATING state. state=CREATING


2391
2392
2393
2394
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2391

class ListDeploymentGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. Field to use to sort the list.

Returns:

  • (::String)

    Optional. Field to use to sort the list.



2391
2392
2393
2394
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2391

class ListDeploymentGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. When requesting a page of resources, 'page_size' specifies number of resources to return. If unspecified, at most 500 will be returned. The maximum value is 1000.

Returns:

  • (::Integer)

    Optional. When requesting a page of resources, 'page_size' specifies number of resources to return. If unspecified, at most 500 will be returned. The maximum value is 1000.



2391
2392
2393
2394
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2391

class ListDeploymentGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Token returned by previous call to 'ListDeploymentGroups' which specifies the position in the list from where to continue listing the deployment groups.

Returns:

  • (::String)

    Optional. Token returned by previous call to 'ListDeploymentGroups' which specifies the position in the list from where to continue listing the deployment groups.



2391
2392
2393
2394
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2391

class ListDeploymentGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent, which owns this collection of deployment groups. Format: 'projects/{project_id}/locations/{location}'.

Returns:

  • (::String)

    Required. The parent, which owns this collection of deployment groups. Format: 'projects/{project_id}/locations/{location}'.



2391
2392
2393
2394
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2391

class ListDeploymentGroupsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end