Class: Google::Cloud::ConfigService::V1::ListResourceDriftsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

A response to a 'ListResourceDrifts' call. Contains a list of ResourceDrifts.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the 'ListResourceDrifts' method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the 'ListResourceDrifts' method. The value of an empty string means that there are no more resources to return.



2108
2109
2110
2111
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2108

class ListResourceDriftsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_drifts::Array<::Google::Cloud::ConfigService::V1::ResourceDrift>

Returns List of ResourceDrifts.

Returns:



2108
2109
2110
2111
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2108

class ListResourceDriftsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unreachable resources, if any.

Returns:

  • (::Array<::String>)

    Unreachable resources, if any.



2108
2109
2110
2111
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2108

class ListResourceDriftsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end