Class: Google::Cloud::ConfigService::V1::Resource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/config/v1/config.rb

Overview

Resource represents a Google Cloud Platform resource actuated by IM. Resources are child resources of Revisions.

Defined Under Namespace

Modules: Intent, State Classes: CaiAssetsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#cai_assets::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::ResourceCAIInfo} (readonly)

Returns Output only. Map of Cloud Asset Inventory (CAI) type to CAI info (e.g. CAI ID). CAI type format follows https://cloud.google.com/asset-inventory/docs/supported-asset-types.

Returns:



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1059

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ConfigService::V1::ResourceCAIInfo]
  class CaiAssetsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible intent of the resource.
  module Intent
    # The default value. This value is used if the intent is omitted.
    INTENT_UNSPECIFIED = 0

    # Infra Manager will create this Resource.
    CREATE = 1

    # Infra Manager will update this Resource.
    UPDATE = 2

    # Infra Manager will delete this Resource.
    DELETE = 3

    # Infra Manager will destroy and recreate this Resource.
    RECREATE = 4

    # Infra Manager will leave this Resource untouched.
    UNCHANGED = 5
  end

  # Possible states of a resource.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # Resource has been planned for reconcile.
    PLANNED = 1

    # Resource is actively reconciling into the intended state.
    IN_PROGRESS = 2

    # Resource has reconciled to intended state.
    RECONCILED = 3

    # Resource failed to reconcile.
    FAILED = 4
  end
end

#intent::Google::Cloud::ConfigService::V1::Resource::Intent (readonly)

Returns Output only. Intent of the resource.

Returns:



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1059

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ConfigService::V1::ResourceCAIInfo]
  class CaiAssetsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible intent of the resource.
  module Intent
    # The default value. This value is used if the intent is omitted.
    INTENT_UNSPECIFIED = 0

    # Infra Manager will create this Resource.
    CREATE = 1

    # Infra Manager will update this Resource.
    UPDATE = 2

    # Infra Manager will delete this Resource.
    DELETE = 3

    # Infra Manager will destroy and recreate this Resource.
    RECREATE = 4

    # Infra Manager will leave this Resource untouched.
    UNCHANGED = 5
  end

  # Possible states of a resource.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # Resource has been planned for reconcile.
    PLANNED = 1

    # Resource is actively reconciling into the intended state.
    IN_PROGRESS = 2

    # Resource has reconciled to intended state.
    RECONCILED = 3

    # Resource failed to reconcile.
    FAILED = 4
  end
end

#name::String (readonly)

Returns Output only. Resource name. Format: projects/{project}/locations/{location}/deployments/{deployment}/revisions/{revision}/resources/{resource}.

Returns:

  • (::String)

    Output only. Resource name. Format: projects/{project}/locations/{location}/deployments/{deployment}/revisions/{revision}/resources/{resource}



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1059

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ConfigService::V1::ResourceCAIInfo]
  class CaiAssetsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible intent of the resource.
  module Intent
    # The default value. This value is used if the intent is omitted.
    INTENT_UNSPECIFIED = 0

    # Infra Manager will create this Resource.
    CREATE = 1

    # Infra Manager will update this Resource.
    UPDATE = 2

    # Infra Manager will delete this Resource.
    DELETE = 3

    # Infra Manager will destroy and recreate this Resource.
    RECREATE = 4

    # Infra Manager will leave this Resource untouched.
    UNCHANGED = 5
  end

  # Possible states of a resource.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # Resource has been planned for reconcile.
    PLANNED = 1

    # Resource is actively reconciling into the intended state.
    IN_PROGRESS = 2

    # Resource has reconciled to intended state.
    RECONCILED = 3

    # Resource failed to reconcile.
    FAILED = 4
  end
end

#state::Google::Cloud::ConfigService::V1::Resource::State (readonly)

Returns Output only. Current state of the resource.

Returns:



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1059

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ConfigService::V1::ResourceCAIInfo]
  class CaiAssetsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible intent of the resource.
  module Intent
    # The default value. This value is used if the intent is omitted.
    INTENT_UNSPECIFIED = 0

    # Infra Manager will create this Resource.
    CREATE = 1

    # Infra Manager will update this Resource.
    UPDATE = 2

    # Infra Manager will delete this Resource.
    DELETE = 3

    # Infra Manager will destroy and recreate this Resource.
    RECREATE = 4

    # Infra Manager will leave this Resource untouched.
    UNCHANGED = 5
  end

  # Possible states of a resource.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # Resource has been planned for reconcile.
    PLANNED = 1

    # Resource is actively reconciling into the intended state.
    IN_PROGRESS = 2

    # Resource has reconciled to intended state.
    RECONCILED = 3

    # Resource failed to reconcile.
    FAILED = 4
  end
end

#terraform_info::Google::Cloud::ConfigService::V1::ResourceTerraformInfo (readonly)

Returns Output only. Terraform-specific info if this resource was created using Terraform.

Returns:



1059
1060
1061
1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1059

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Google::Cloud::ConfigService::V1::ResourceCAIInfo]
  class CaiAssetsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Possible intent of the resource.
  module Intent
    # The default value. This value is used if the intent is omitted.
    INTENT_UNSPECIFIED = 0

    # Infra Manager will create this Resource.
    CREATE = 1

    # Infra Manager will update this Resource.
    UPDATE = 2

    # Infra Manager will delete this Resource.
    DELETE = 3

    # Infra Manager will destroy and recreate this Resource.
    RECREATE = 4

    # Infra Manager will leave this Resource untouched.
    UNCHANGED = 5
  end

  # Possible states of a resource.
  module State
    # The default value. This value is used if the state is omitted.
    STATE_UNSPECIFIED = 0

    # Resource has been planned for reconcile.
    PLANNED = 1

    # Resource is actively reconciling into the intended state.
    IN_PROGRESS = 2

    # Resource has reconciled to intended state.
    RECONCILED = 3

    # Resource failed to reconcile.
    FAILED = 4
  end
end