Class: Google::Cloud::ConfigService::V1::TerraformVersion
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::TerraformVersion
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
A TerraformVersion represents the support state the corresponding Terraform version.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#deprecate_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#obsolete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#state ⇒ ::Google::Cloud::ConfigService::V1::TerraformVersion::State
readonly
Output only.
-
#support_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#deprecate_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the version is deprecated.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1824 class TerraformVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a TerraformVersion. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The version is actively supported. ACTIVE = 1 # The version is deprecated. DEPRECATED = 2 # The version is obsolete. OBSOLETE = 3 end end |
#name ⇒ ::String
Returns Identifier. The version name is in the format: 'projects/{project_id}/locations/{location}/terraformVersions/{terraform_version}'.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1824 class TerraformVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a TerraformVersion. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The version is actively supported. ACTIVE = 1 # The version is deprecated. DEPRECATED = 2 # The version is obsolete. OBSOLETE = 3 end end |
#obsolete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the version is obsolete.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1824 class TerraformVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a TerraformVersion. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The version is actively supported. ACTIVE = 1 # The version is deprecated. DEPRECATED = 2 # The version is obsolete. OBSOLETE = 3 end end |
#state ⇒ ::Google::Cloud::ConfigService::V1::TerraformVersion::State (readonly)
Returns Output only. The state of the version, ACTIVE, DEPRECATED or OBSOLETE.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1824 class TerraformVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a TerraformVersion. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The version is actively supported. ACTIVE = 1 # The version is deprecated. DEPRECATED = 2 # The version is obsolete. OBSOLETE = 3 end end |
#support_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the version is supported.
1824 1825 1826 1827 1828 1829 1830 1831 1832 1833 1834 1835 1836 1837 1838 1839 1840 1841 1842 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1824 class TerraformVersion include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible states of a TerraformVersion. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The version is actively supported. ACTIVE = 1 # The version is deprecated. DEPRECATED = 2 # The version is obsolete. OBSOLETE = 3 end end |