Class: Google::Cloud::ConfigService::V1::DeleteDeploymentGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::DeleteDeploymentGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
Request message for Delete DeploymentGroup
Defined Under Namespace
Modules: DeploymentReferencePolicy
Instance Attribute Summary collapse
-
#deployment_reference_policy ⇒ ::Google::Cloud::ConfigService::V1::DeleteDeploymentGroupRequest::DeploymentReferencePolicy
Optional.
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#deployment_reference_policy ⇒ ::Google::Cloud::ConfigService::V1::DeleteDeploymentGroupRequest::DeploymentReferencePolicy
Returns Optional. Policy on how to handle referenced deployments when deleting the
DeploymentGroup.
If unspecified, the default behavior is to fail the deletion if any
deployments currently referenced in the deployment_units of the
DeploymentGroup or in the latest revision are not deleted.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 631 class DeleteDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Policy on how to handle referenced deployments when deleting the # DeploymentGroup. module DeploymentReferencePolicy # The default behavior. If unspecified, the system will act as if # `FAIL_IF_ANY_REFERENCES_EXIST` is specified. DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED = 0 # Fail the deletion if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision # are not deleted. FAIL_IF_ANY_REFERENCES_EXIST = 1 # Fail the deletion only if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup are not deleted. # The deletion will proceed even if the deployments in the latest revision # of the DeploymentGroup are not deleted. FAIL_IF_METADATA_REFERENCES_EXIST = 2 # Ignore any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision. IGNORE_DEPLOYMENT_REFERENCES = 3 end end |
#force ⇒ ::Boolean
Returns Optional. If set to true, any revisions for this deployment group will also be deleted. (Otherwise, the request will only work if the deployment group has no revisions.).
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 631 class DeleteDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Policy on how to handle referenced deployments when deleting the # DeploymentGroup. module DeploymentReferencePolicy # The default behavior. If unspecified, the system will act as if # `FAIL_IF_ANY_REFERENCES_EXIST` is specified. DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED = 0 # Fail the deletion if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision # are not deleted. FAIL_IF_ANY_REFERENCES_EXIST = 1 # Fail the deletion only if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup are not deleted. # The deletion will proceed even if the deployments in the latest revision # of the DeploymentGroup are not deleted. FAIL_IF_METADATA_REFERENCES_EXIST = 2 # Ignore any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision. IGNORE_DEPLOYMENT_REFERENCES = 3 end end |
#name ⇒ ::String
Returns Required. The name of DeploymentGroup in the format projects/{project_id}/locations/{location_id}/deploymentGroups/{deploymentGroup}.
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 631 class DeleteDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Policy on how to handle referenced deployments when deleting the # DeploymentGroup. module DeploymentReferencePolicy # The default behavior. If unspecified, the system will act as if # `FAIL_IF_ANY_REFERENCES_EXIST` is specified. DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED = 0 # Fail the deletion if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision # are not deleted. FAIL_IF_ANY_REFERENCES_EXIST = 1 # Fail the deletion only if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup are not deleted. # The deletion will proceed even if the deployments in the latest revision # of the DeploymentGroup are not deleted. FAIL_IF_METADATA_REFERENCES_EXIST = 2 # Ignore any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision. IGNORE_DEPLOYMENT_REFERENCES = 3 end end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 631 class DeleteDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Policy on how to handle referenced deployments when deleting the # DeploymentGroup. module DeploymentReferencePolicy # The default behavior. If unspecified, the system will act as if # `FAIL_IF_ANY_REFERENCES_EXIST` is specified. DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED = 0 # Fail the deletion if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision # are not deleted. FAIL_IF_ANY_REFERENCES_EXIST = 1 # Fail the deletion only if any deployments currently referenced in the # `deployment_units` of the DeploymentGroup are not deleted. # The deletion will proceed even if the deployments in the latest revision # of the DeploymentGroup are not deleted. FAIL_IF_METADATA_REFERENCES_EXIST = 2 # Ignore any deployments currently referenced in the # `deployment_units` of the DeploymentGroup or in the latest revision. IGNORE_DEPLOYMENT_REFERENCES = 3 end end |