Module: Google::Cloud::ConfigService::V1::DeleteDeploymentGroupRequest::DeploymentReferencePolicy
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
Policy on how to handle referenced deployments when deleting the DeploymentGroup.
Constant Summary collapse
- DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED =
The default behavior. If unspecified, the system will act as if
FAIL_IF_ANY_REFERENCES_EXISTis specified. 0- FAIL_IF_ANY_REFERENCES_EXIST =
Fail the deletion if any deployments currently referenced in the
deployment_unitsof the DeploymentGroup or in the latest revision are not deleted. 1- FAIL_IF_METADATA_REFERENCES_EXIST =
Fail the deletion only if any deployments currently referenced in the
deployment_unitsof the DeploymentGroup are not deleted. The deletion will proceed even if the deployments in the latest revision of the DeploymentGroup are not deleted. 2- IGNORE_DEPLOYMENT_REFERENCES =
Ignore any deployments currently referenced in the
deployment_unitsof the DeploymentGroup or in the latest revision. 3