Class: Google::Cloud::ConfigService::V1::DeploymentGroupRevision
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::DeploymentGroupRevision
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
A DeploymentGroupRevision represents a snapshot of a DeploymentGroup at a given point in time, created when a DeploymentGroup is provisioned or deprovisioned.
Instance Attribute Summary collapse
-
#alternative_ids ⇒ ::Array<::String>
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#name ⇒ ::String
Identifier.
-
#snapshot ⇒ ::Google::Cloud::ConfigService::V1::DeploymentGroup
readonly
Output only.
Instance Attribute Details
#alternative_ids ⇒ ::Array<::String> (readonly)
Returns Output only. The alternative IDs of the deployment group revision.
2631 2632 2633 2634 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2631 class DeploymentGroupRevision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when the deployment group revision was created.
2631 2632 2633 2634 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2631 class DeploymentGroupRevision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Identifier. The name of the deployment group revision. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}/revisions/{revision}'.
2631 2632 2633 2634 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2631 class DeploymentGroupRevision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snapshot ⇒ ::Google::Cloud::ConfigService::V1::DeploymentGroup (readonly)
Returns Output only. The snapshot of the deployment group at this revision.
2631 2632 2633 2634 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2631 class DeploymentGroupRevision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |