Class: Google::Cloud::ConfigService::V1::DeploymentSource
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::DeploymentSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
Configuration for a value sourced from a Deployment.
Instance Attribute Summary collapse
-
#deployment ⇒ ::String
Required.
-
#output_name ⇒ ::String
Required.
Instance Attribute Details
#deployment ⇒ ::String
Returns Required. The resource name of the source Deployment to import the output from. Format: projects/{project}/locations/{location}/deployments/{deployment} The source deployment must be in the same project and location.
314 315 316 317 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 314 class DeploymentSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_name ⇒ ::String
Returns Required. The name of the output variable in the source deployment's latest successfully applied revision.
314 315 316 317 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 314 class DeploymentSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |