Class: Google::Cloud::ConfigService::V1::DeploymentUnit
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::DeploymentUnit
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
A DeploymentUnit is a container for a deployment and its dependencies.
An existing deployment can be provided directly in the unit, or the unit
can act as a placeholder to define the DAG, with the deployment specs
supplied in a provisionDeploymentRequest.
Instance Attribute Summary collapse
-
#dependencies ⇒ ::Array<::String>
Required.
-
#deployment ⇒ ::String
Optional.
-
#id ⇒ ::String
The id of the deployment unit.
Instance Attribute Details
#dependencies ⇒ ::Array<::String>
Returns Required. The IDs of the deployment units within the deployment group that this unit depends on.
2320 2321 2322 2323 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2320 class DeploymentUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#deployment ⇒ ::String
Returns Optional. The name of the deployment to be provisioned. Format: 'projects/{project_id}/locations/{location}/deployments/{deployment}'.
2320 2321 2322 2323 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2320 class DeploymentUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns The id of the deployment unit. Must be unique within the deployment group.
2320 2321 2322 2323 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2320 class DeploymentUnit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |