Module: Google::Cloud::ConfigService::V1::DeploymentUnitProgress::State
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
The possible steps a deployment unit provisioning may be running.
Constant Summary collapse
- STATE_UNSPECIFIED =
The default value. This value is unused.
0- QUEUED =
The deployment unit is queued for deployment creation or update.
1- APPLYING_DEPLOYMENT =
The underlying deployment of the unit is being created or updated.
2- SUCCEEDED =
The underlying deployment operation of the unit has succeeded.
4- FAILED =
The underlying deployment operation of the unit has failed.
5- ABORTED =
The deployment unit was aborted, likely due to failures in other dependent deployment units.
6- SKIPPED =
The deployment unit was skipped because there were no changes to apply.
7- DELETING_DEPLOYMENT =
The deployment is being deleted.
8- PREVIEWING_DEPLOYMENT =
The deployment is being previewed.
9