Class: Google::Cloud::ConfigService::V1::DeprovisionDeploymentGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::DeprovisionDeploymentGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
The request message for the DeprovisionDeploymentGroup method.
Instance Attribute Summary collapse
-
#delete_policy ⇒ ::Google::Cloud::ConfigService::V1::DeleteDeploymentRequest::DeletePolicy
Optional.
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#delete_policy ⇒ ::Google::Cloud::ConfigService::V1::DeleteDeploymentRequest::DeletePolicy
Returns Optional. Policy on how resources within each deployment should be handled during deletion. This policy is applied globally to the deletion of all deployments in this group. This corresponds to the 'delete_policy' field in DeleteDeploymentRequest.
2458 2459 2460 2461 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2458 class DeprovisionDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#force ⇒ ::Boolean
Returns Optional. If set to true, this option is propagated to the deletion of each deployment in the group. This corresponds to the 'force' field in DeleteDeploymentRequest.
2458 2459 2460 2461 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2458 class DeprovisionDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the deployment group to deprovision. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.
2458 2459 2460 2461 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2458 class DeprovisionDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |