Class: Google::Cloud::ConfigService::V1::ListResourceChangesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::ListResourceChangesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
A response to a 'ListResourceChanges' call. Contains a list of ResourceChanges.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token to request the next page of resources from the 'ListResourceChanges' method.
-
#resource_changes ⇒ ::Array<::Google::Cloud::ConfigService::V1::ResourceChange>
List of ResourceChanges.
-
#unreachable ⇒ ::Array<::String>
Unreachable resources, if any.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token to request the next page of resources from the 'ListResourceChanges' method. The value of an empty string means that there are no more resources to return.
1982 1983 1984 1985 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1982 class ListResourceChangesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_changes ⇒ ::Array<::Google::Cloud::ConfigService::V1::ResourceChange>
Returns List of ResourceChanges.
1982 1983 1984 1985 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1982 class ListResourceChangesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns Unreachable resources, if any.
1982 1983 1984 1985 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1982 class ListResourceChangesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |