Class: Google::Cloud::ConfigService::V1::PreviewOperationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::PreviewOperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
Ephemeral metadata content describing the state of a preview operation.
Defined Under Namespace
Modules: PreviewStep
Instance Attribute Summary collapse
-
#build ⇒ ::String
readonly
Output only.
-
#logs ⇒ ::String
readonly
Output only.
-
#preview_artifacts ⇒ ::Google::Cloud::ConfigService::V1::PreviewArtifacts
Artifacts from preview.
-
#step ⇒ ::Google::Cloud::ConfigService::V1::PreviewOperationMetadata::PreviewStep
The current step the preview operation is running.
Instance Attribute Details
#build ⇒ ::String (readonly)
Returns Output only. Cloud Build instance UUID associated with this preview.
1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1530 class PreviewOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The possible steps a preview may be running. module PreviewStep # Unspecified preview step. PREVIEW_STEP_UNSPECIFIED = 0 # Infra Manager is creating a Google Cloud Storage bucket to store # artifacts and metadata about the preview. PREPARING_STORAGE_BUCKET = 1 # Downloading the blueprint onto the Google Cloud Storage bucket. DOWNLOADING_BLUEPRINT = 2 # Initializing Terraform using `terraform init`. RUNNING_TF_INIT = 3 # Running `terraform plan`. RUNNING_TF_PLAN = 4 # Fetching a deployment. FETCHING_DEPLOYMENT = 5 # Locking a deployment. LOCKING_DEPLOYMENT = 6 # Unlocking a deployment. UNLOCKING_DEPLOYMENT = 7 # Operation was successful. SUCCEEDED = 8 # Operation failed. FAILED = 9 # Validating the provided repository. VALIDATING_REPOSITORY = 10 end end |
#logs ⇒ ::String (readonly)
Returns Output only. Location of preview logs in gs://{bucket}/{object} format.
1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1530 class PreviewOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The possible steps a preview may be running. module PreviewStep # Unspecified preview step. PREVIEW_STEP_UNSPECIFIED = 0 # Infra Manager is creating a Google Cloud Storage bucket to store # artifacts and metadata about the preview. PREPARING_STORAGE_BUCKET = 1 # Downloading the blueprint onto the Google Cloud Storage bucket. DOWNLOADING_BLUEPRINT = 2 # Initializing Terraform using `terraform init`. RUNNING_TF_INIT = 3 # Running `terraform plan`. RUNNING_TF_PLAN = 4 # Fetching a deployment. FETCHING_DEPLOYMENT = 5 # Locking a deployment. LOCKING_DEPLOYMENT = 6 # Unlocking a deployment. UNLOCKING_DEPLOYMENT = 7 # Operation was successful. SUCCEEDED = 8 # Operation failed. FAILED = 9 # Validating the provided repository. VALIDATING_REPOSITORY = 10 end end |
#preview_artifacts ⇒ ::Google::Cloud::ConfigService::V1::PreviewArtifacts
Returns Artifacts from preview.
1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1530 class PreviewOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The possible steps a preview may be running. module PreviewStep # Unspecified preview step. PREVIEW_STEP_UNSPECIFIED = 0 # Infra Manager is creating a Google Cloud Storage bucket to store # artifacts and metadata about the preview. PREPARING_STORAGE_BUCKET = 1 # Downloading the blueprint onto the Google Cloud Storage bucket. DOWNLOADING_BLUEPRINT = 2 # Initializing Terraform using `terraform init`. RUNNING_TF_INIT = 3 # Running `terraform plan`. RUNNING_TF_PLAN = 4 # Fetching a deployment. FETCHING_DEPLOYMENT = 5 # Locking a deployment. LOCKING_DEPLOYMENT = 6 # Unlocking a deployment. UNLOCKING_DEPLOYMENT = 7 # Operation was successful. SUCCEEDED = 8 # Operation failed. FAILED = 9 # Validating the provided repository. VALIDATING_REPOSITORY = 10 end end |
#step ⇒ ::Google::Cloud::ConfigService::V1::PreviewOperationMetadata::PreviewStep
Returns The current step the preview operation is running.
1530 1531 1532 1533 1534 1535 1536 1537 1538 1539 1540 1541 1542 1543 1544 1545 1546 1547 1548 1549 1550 1551 1552 1553 1554 1555 1556 1557 1558 1559 1560 1561 1562 1563 1564 1565 1566 1567 1568 1569 1570 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 1530 class PreviewOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The possible steps a preview may be running. module PreviewStep # Unspecified preview step. PREVIEW_STEP_UNSPECIFIED = 0 # Infra Manager is creating a Google Cloud Storage bucket to store # artifacts and metadata about the preview. PREPARING_STORAGE_BUCKET = 1 # Downloading the blueprint onto the Google Cloud Storage bucket. DOWNLOADING_BLUEPRINT = 2 # Initializing Terraform using `terraform init`. RUNNING_TF_INIT = 3 # Running `terraform plan`. RUNNING_TF_PLAN = 4 # Fetching a deployment. FETCHING_DEPLOYMENT = 5 # Locking a deployment. LOCKING_DEPLOYMENT = 6 # Unlocking a deployment. UNLOCKING_DEPLOYMENT = 7 # Operation was successful. SUCCEEDED = 8 # Operation failed. FAILED = 9 # Validating the provided repository. VALIDATING_REPOSITORY = 10 end end |