Class: Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupOperationMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupOperationMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
Operation metadata for ProvisionDeploymentGroup and
DeprovisionDeploymentGroup long-running operations.
Defined Under Namespace
Modules: ProvisionDeploymentGroupStep
Instance Attribute Summary collapse
-
#deployment_unit_progresses ⇒ ::Array<::Google::Cloud::ConfigService::V1::DeploymentUnitProgress>
readonly
Output only.
-
#step ⇒ ::Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupOperationMetadata::ProvisionDeploymentGroupStep
readonly
Output only.
Instance Attribute Details
#deployment_unit_progresses ⇒ ::Array<::Google::Cloud::ConfigService::V1::DeploymentUnitProgress> (readonly)
Returns Output only. Progress information for each deployment unit within the operation.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2581 class ProvisionDeploymentGroupOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible steps during a deployment group provisioning or deprovisioning # operation. module ProvisionDeploymentGroupStep # Unspecified step. PROVISION_DEPLOYMENT_GROUP_STEP_UNSPECIFIED = 0 # Validating the deployment group. VALIDATING_DEPLOYMENT_GROUP = 1 # Locking the deployments to the deployment group for atomic actuation. ASSOCIATING_DEPLOYMENTS_TO_DEPLOYMENT_GROUP = 2 # Provisioning the deployment units. PROVISIONING_DEPLOYMENT_UNITS = 3 # Unlocking the deployments from the deployment group after actuation. DISASSOCIATING_DEPLOYMENTS_FROM_DEPLOYMENT_GROUP = 4 # The operation has succeeded. SUCCEEDED = 5 # The operation has failed. FAILED = 6 # Deprovisioning the deployment units. DEPROVISIONING_DEPLOYMENT_UNITS = 7 end end |
#step ⇒ ::Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupOperationMetadata::ProvisionDeploymentGroupStep (readonly)
Returns Output only. The current step of the deployment group operation.
2581 2582 2583 2584 2585 2586 2587 2588 2589 2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2581 class ProvisionDeploymentGroupOperationMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible steps during a deployment group provisioning or deprovisioning # operation. module ProvisionDeploymentGroupStep # Unspecified step. PROVISION_DEPLOYMENT_GROUP_STEP_UNSPECIFIED = 0 # Validating the deployment group. VALIDATING_DEPLOYMENT_GROUP = 1 # Locking the deployments to the deployment group for atomic actuation. ASSOCIATING_DEPLOYMENTS_TO_DEPLOYMENT_GROUP = 2 # Provisioning the deployment units. PROVISIONING_DEPLOYMENT_UNITS = 3 # Unlocking the deployments from the deployment group after actuation. DISASSOCIATING_DEPLOYMENTS_FROM_DEPLOYMENT_GROUP = 4 # The operation has succeeded. SUCCEEDED = 5 # The operation has failed. FAILED = 6 # Deprovisioning the deployment units. DEPROVISIONING_DEPLOYMENT_UNITS = 7 end end |