Class: Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupRequest
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::ProvisionDeploymentGroupRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
The request message for the ProvisionDeploymentGroup method.
Defined Under Namespace
Classes: DeploymentSpecsEntry
Instance Attribute Summary collapse
-
#deployment_specs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::DeploymentSpec}
Optional.
-
#name ⇒ ::String
Required.
Instance Attribute Details
#deployment_specs ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::DeploymentSpec}
Returns Optional. The deployment specs of the deployment units to be created within
the same project and location of the deployment group. The key is the unit
ID, and the value is the DeploymentSpec. Provisioning will fail if a
deployment_spec has a deployment_id that matches an existing deployment
in the same project and location. If an existing deployment was part of the
last successful revision but is no longer in the current DeploymentGroup's
deployment_units, it will be recreated if included in deployment_specs.
2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2427 class ProvisionDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::DeploymentSpec] class DeploymentSpecsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Required. The name of the deployment group to provision. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'.
2427 2428 2429 2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 2427 class ProvisionDeploymentGroupRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::DeploymentSpec] class DeploymentSpecsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |