Class: Google::Cloud::ConfigService::V1::Revision
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::Revision
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
A child resource of a Deployment generated by a 'CreateDeployment' or 'UpdateDeployment' call. Each Revision contains metadata pertaining to a snapshot of a particular Deployment.
Defined Under Namespace
Modules: Action, ErrorCode, State
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::ConfigService::V1::Revision::Action
readonly
Output only.
-
#apply_results ⇒ ::Google::Cloud::ConfigService::V1::ApplyResults
readonly
Output only.
-
#build ⇒ ::String
readonly
Output only.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#error_code ⇒ ::Google::Cloud::ConfigService::V1::Revision::ErrorCode
readonly
Output only.
-
#error_logs ⇒ ::String
readonly
Output only.
-
#import_existing_resources ⇒ ::Boolean
readonly
Output only.
-
#logs ⇒ ::String
readonly
Output only.
-
#name ⇒ ::String
Revision name.
-
#provider_config ⇒ ::Google::Cloud::ConfigService::V1::ProviderConfig
readonly
Output only.
-
#quota_validation ⇒ ::Google::Cloud::ConfigService::V1::QuotaValidation
Optional.
-
#quota_validation_results ⇒ ::String
readonly
Output only.
-
#service_account ⇒ ::String
readonly
Output only.
-
#state ⇒ ::Google::Cloud::ConfigService::V1::Revision::State
readonly
Output only.
-
#state_detail ⇒ ::String
readonly
Output only.
-
#terraform_blueprint ⇒ ::Google::Cloud::ConfigService::V1::TerraformBlueprint
readonly
Output only.
-
#tf_errors ⇒ ::Array<::Google::Cloud::ConfigService::V1::TerraformError>
readonly
Output only.
-
#tf_version ⇒ ::String
readonly
Output only.
-
#tf_version_constraint ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#worker_pool ⇒ ::String
readonly
Output only.
Instance Attribute Details
#action ⇒ ::Google::Cloud::ConfigService::V1::Revision::Action (readonly)
Returns Output only. The action which created this revision.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#apply_results ⇒ ::Google::Cloud::ConfigService::V1::ApplyResults (readonly)
Returns Output only. Outputs and artifacts from applying a deployment.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#build ⇒ ::String (readonly)
Returns Output only. Cloud Build instance UUID associated with this revision.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when the revision was created.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#error_code ⇒ ::Google::Cloud::ConfigService::V1::Revision::ErrorCode (readonly)
Returns Output only. Code describing any errors that may have occurred.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#error_logs ⇒ ::String (readonly)
Returns Output only. Location of Terraform error logs in Google Cloud Storage.
Format: gs://{bucket}/{object}.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#import_existing_resources ⇒ ::Boolean (readonly)
Returns Output only. By default, Infra Manager will return a failure when Terraform encounters a 409 code (resource conflict error) during actuation. If this flag is set to true, Infra Manager will instead attempt to automatically import the resource into the Terraform state (for supported resource types) and continue actuation.
Not all resource types are supported, refer to documentation.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#logs ⇒ ::String (readonly)
Returns Output only. Location of Revision operation logs in
gs://{bucket}/{object} format.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#name ⇒ ::String
Returns Revision name. Format:
projects/{project}/locations/{location}/deployments/{deployment}/
revisions/\\{revision}.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#provider_config ⇒ ::Google::Cloud::ConfigService::V1::ProviderConfig (readonly)
Returns Output only. This field specifies the provider configurations.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#quota_validation ⇒ ::Google::Cloud::ConfigService::V1::QuotaValidation
Returns Optional. Input to control quota checks for resources in terraform configuration files. There are limited resources on which quota validation applies.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#quota_validation_results ⇒ ::String (readonly)
Returns Output only. Cloud Storage path containing quota validation results. This
field is set when a user sets Deployment.quota_validation field to ENABLED
or ENFORCED. Format: gs://{bucket}/{object}.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#service_account ⇒ ::String (readonly)
Returns Output only. User-specified Service Account (SA) to be used as credential
to manage resources. Format:
projects/{projectID}/serviceAccounts/{serviceAccount}.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#state ⇒ ::Google::Cloud::ConfigService::V1::Revision::State (readonly)
Returns Output only. Current state of the revision.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#state_detail ⇒ ::String (readonly)
Returns Output only. Additional info regarding the current state.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#terraform_blueprint ⇒ ::Google::Cloud::ConfigService::V1::TerraformBlueprint (readonly)
Returns Output only. A blueprint described using Terraform's HashiCorp Configuration Language as a root module.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#tf_errors ⇒ ::Array<::Google::Cloud::ConfigService::V1::TerraformError> (readonly)
Returns Output only. Errors encountered when creating or updating this deployment.
Errors are truncated to 10 entries, see delete_results and error_logs
for full details.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#tf_version ⇒ ::String (readonly)
Returns Output only. The version of Terraform used to create the Revision. It is in the format of "Major.Minor.Patch", for example, "1.3.10".
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#tf_version_constraint ⇒ ::String (readonly)
Returns Output only. The user-specified Terraform version constraint. Example: "=1.3.10".
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Time when the revision was last modified.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |
#worker_pool ⇒ ::String (readonly)
Returns Output only. The user-specified Cloud Build worker pool resource in which
the Cloud Build job will execute. Format:
projects/{project}/locations/{location}/workerPools/{workerPoolId}.
If this field is unspecified, the default Cloud Build worker pool will be
used.
877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 877 class Revision include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Actions that generate a revision. module Action # The default value. This value is used if the action is omitted. ACTION_UNSPECIFIED = 0 # The revision was generated by creating a deployment. CREATE = 1 # The revision was generated by updating a deployment. UPDATE = 2 # The revision was deleted. DELETE = 3 end # Possible states of a revision. module State # The default value. This value is used if the state is omitted. STATE_UNSPECIFIED = 0 # The revision is being applied. APPLYING = 1 # The revision was applied successfully. APPLIED = 2 # The revision could not be applied successfully. FAILED = 3 end # Possible errors if Revision could not be created or updated successfully. module ErrorCode # No error code was specified. ERROR_CODE_UNSPECIFIED = 0 # Cloud Build failed due to a permission issue. CLOUD_BUILD_PERMISSION_DENIED = 1 # Cloud Build job associated with creating or updating a deployment could # not be started. APPLY_BUILD_API_FAILED = 4 # Cloud Build job associated with creating or updating a deployment was # started but failed. APPLY_BUILD_RUN_FAILED = 5 # quota validation failed for one or more resources in terraform # configuration files. QUOTA_VALIDATION_FAILED = 7 # Failed to import values from an external source. EXTERNAL_VALUE_SOURCE_IMPORT_FAILED = 8 end end |