Class: Google::Cloud::ConfigService::V1::TerraformBlueprint
- Inherits:
-
Object
- Object
- Google::Cloud::ConfigService::V1::TerraformBlueprint
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/config/v1/config.rb
Overview
TerraformBlueprint describes the source of a Terraform root module which describes the resources and configs to be deployed.
Defined Under Namespace
Classes: ExternalValuesEntry, InputValuesEntry
Instance Attribute Summary collapse
-
#external_values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::ExternalValueSource}
Optional.
-
#gcs_source ⇒ ::String
URI of an object in Google Cloud Storage.
-
#git_source ⇒ ::Google::Cloud::ConfigService::V1::GitSource
URI of a public Git repo.
-
#input_values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::TerraformVariable}
Optional.
Instance Attribute Details
#external_values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::ExternalValueSource}
Returns Optional. Map of input variable names in this blueprint to configurations for importing values from external sources.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 262 class TerraformBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::TerraformVariable] class InputValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::ExternalValueSource] class ExternalValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#gcs_source ⇒ ::String
Returns URI of an object in Google Cloud Storage.
Format: gs://{bucket}/{object}
URI may also specify an object version for zipped objects.
Format: gs://{bucket}/{object}#{version}
Note: The following fields are mutually exclusive: gcs_source, git_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 262 class TerraformBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::TerraformVariable] class InputValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::ExternalValueSource] class ExternalValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#git_source ⇒ ::Google::Cloud::ConfigService::V1::GitSource
Returns URI of a public Git repo.
Note: The following fields are mutually exclusive: git_source, gcs_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 262 class TerraformBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::TerraformVariable] class InputValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::ExternalValueSource] class ExternalValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#input_values ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::ConfigService::V1::TerraformVariable}
Returns Optional. Input variable values for the Terraform blueprint.
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'proto_docs/google/cloud/config/v1/config.rb', line 262 class TerraformBlueprint include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::TerraformVariable] class InputValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::ConfigService::V1::ExternalValueSource] class ExternalValuesEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |